# ReVibe Documentation

Welcome to the ReVibe documentation! For basic setup, see the [main README](https://github.com/OEvortex/revibe#readme).

ReVibe is a multi-provider CLI coding agent with a clean, minimal interface.

## Available Documentation

- **[ACP Setup](acp-setup.md)** - Setup instructions for using ReVibe with various editors and IDEs that support the Agent Client Protocol.
